<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
	<!ENTITY nbsp "&#x00A0;">
]>
<xsl:stylesheet
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:msxml="urn:schemas-microsoft-com:xslt"
	xmlns:umbraco.library="urn:umbraco.library"
	xmlns:CommerceLibrary="urn:CommerceLibrary"
	exclude-result-prefixes="msxml umbraco.library CommerceLibrary">


	<xsl:output method="xml" omit-xml-declaration="yes"/>

	<xsl:param name="currentPage"/>


	<xsl:template match="/">

		<script type="text/javascript">
			<![CDATA[
				$(document).ready(function() {
					$('.toggleDiscount').click(function() {
						var toggleId = $(this).attr('toggleid');
						toggleDiscount(toggleId);       
					});
				});
			
				function toggleDiscount(id)
				{
          $('#'+id).slideToggle('normal');       
        }
			]]>
		</script>

		<!-- Check if there's any post back -->
		<xsl:variable name="isPostback" select="umbraco.library:RequestForm('quantityInput_0')"/>

		<xsl:if test="string-length(umbraco.library:RequestForm('voucherCode'))">
			<xsl:call-template name="addVoucherTemplate"></xsl:call-template>	
		</xsl:if>
		
		<xsl:if test="string-length($isPostback)">
			<xsl:call-template name="updateBasketTemplate"></xsl:call-template>
		</xsl:if>
		

		<xsl:choose>
			<xsl:when test="CommerceLibrary:HasBasket()">
				<xsl:call-template name="basketTemplate"></xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				Your basket is empty.
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="basketTemplate">
		<form method="post">
			<xsl:variable name="cart" select="CommerceLibrary:GetBasket()"/>
			<table>
				<tr>
					<th></th>
					<th>Item no.</th>
					<th>Description</th>
					<th>Item price</th>
					<th>VAT</th>
					<th>Quantity</th>
					<th>Total</th>
				</tr>
				<xsl:for-each select="$cart/purchaseOrder/lineItems/lineItem">
					<tr>
						<td>
							<span style="cursor:pointer;" class="toggleDiscount">
								<xsl:attribute name="toggleid">discount_<xsl:value-of select="@index" /></xsl:attribute>
								<img src="/Images/expand.png" alt="Show discounts" title="Show discounts" />
							</span>
						</td>
						<td>
							<xsl:value-of select="@sku"/>
						</td>
						<td>
							<xsl:value-of select="@productName"/>
						</td>
						<td>
							<xsl:choose>
								<xsl:when test="@unitDiscount != 0">
									<span style="text-decoration:line-through">
										<xsl:value-of select="CommerceLibrary:FormatCurrency(@price)"/>
									</span>&nbsp;
									<xsl:value-of select="CommerceLibrary:FormatCurrency(@price - @unitDiscount)"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="CommerceLibrary:FormatCurrency(@price)"/>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td>
							<xsl:value-of select="CommerceLibrary:FormatCurrency(@vat)"/>
						</td>
						<td>
							<input type="text" class="quantityInput">
								<xsl:attribute name="value">
									<xsl:value-of select="@quantity"/>
								</xsl:attribute>
								<xsl:attribute name="name">quantityInput_<xsl:value-of select="@index"/></xsl:attribute>
							</input>
						</td>
						<td>
							<xsl:value-of select="CommerceLibrary:FormatCurrency(@total)"/>
						</td>
					</tr>
					<tr>
						<td></td>
						<td colspan="6">
							<xsl:call-template name="discountTemplate">
								<xsl:with-param name="discounts" select="discounts"/>
								<xsl:with-param name="id" select="@index"/>
							</xsl:call-template>
						</td>
					</tr>

				</xsl:for-each>
				<tr>
					<td></td>
					<td colspan="5">Sub total:</td>
					<td>
						<xsl:value-of select="CommerceLibrary:FormatCurrency($cart/purchaseOrder/@subTotal)"/>
					</td>
				</tr>
				<tr>
					<td></td>
					<td colspan="5">VAT:</td>
					<td>
						<xsl:value-of select="CommerceLibrary:FormatCurrency($cart/purchaseOrder/@vat)"/>
					</td>
				</tr>
				<tr>
					<td>
						<span style="cursor:pointer;" class="toggleDiscount">
							<xsl:attribute name="toggleid">discount_<xsl:value-of select="@orderGuid" /></xsl:attribute>
							<img src="/Images/expand.png" alt="Show discounts" title="Show discounts" />
						</span>
					</td>
					<td colspan="5">Order discounts:</td>
					<td>
						-<xsl:value-of select="CommerceLibrary:FormatCurrency($cart/purchaseOrder/@discount)"/>
					</td>
				</tr>
				<tr>
					<td></td>
					<td colspan="6">
						<xsl:call-template name="discountTemplate">
							<xsl:with-param name="discounts" select="$cart/purchaseOrder/discounts"/>
							<xsl:with-param name="id" select="@orderGuid"/>
						</xsl:call-template>
					</td>
				</tr>
				<tr>
					<td></td>
					<td colspan="5">Order total:</td>
					<td>
						<xsl:value-of select="CommerceLibrary:FormatCurrency($cart/purchaseOrder/@orderTotal)"/>
					</td>
				</tr>
			</table>
			<br />
			<input type="text" name="voucherCode"></input>
			<input type="submit" value="Add voucher"></input>
			<br />
			<br />
			<input type="submit" value="Update Cart"></input> - <a href="address.aspx">Proceed to address information</a>
		</form>
	</xsl:template>

	<xsl:template name="discountTemplate">
		<xsl:param name="discounts" />
		<xsl:param name="id" />

		<xsl:if test="count($discounts/discount) > 0">
			<div style="width:100%; display:none;">
				<xsl:attribute name="id">discount_<xsl:value-of select="$id" /></xsl:attribute>
				<table cellpadding="0" cellspacing="0" style="width:100%;">
					<xsl:for-each select="$discounts/discount">
						<tr style="background-color:#eeeeee">
							<td></td>
							<td colspan="6" style="padding-left:20px;">
								<xsl:value-of select="@campaignName"/> - <xsl:value-of select="@campaignItemName"/> - <xsl:value-of select="@description"/>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</div>
		</xsl:if>
	</xsl:template>

	<xsl:template name="updateBasketTemplate">
		<xsl:if test="CommerceLibrary:HasBasket()">
			<xsl:for-each select="CommerceLibrary:GetBasket()/purchaseOrder/lineItems/lineItem">
				<!-- Update highest index first in case we're deleting thus shrinking the list -->
				<xsl:sort select="@index" data-type="number" order="descending"/>

				<!-- Find the name of the posted quantity change -->
				<xsl:variable name="postedQuantity" select="umbraco.library:RequestForm(concat('quantityInput_', @index))"/>
				<xsl:variable name="result" select="CommerceLibrary:UpdateLineItem(@index, $postedQuantity)"></xsl:variable>
			</xsl:for-each>
			<xsl:variable name="pipelineResult" select="CommerceLibrary:ExecuteBasketPipeline()"></xsl:variable>
		</xsl:if>
	</xsl:template>

	<xsl:template name="addVoucherTemplate">
		<xsl:variable name="voucherAdded" select="CommerceLibrary:AddVoucher(umbraco.library:RequestForm('voucherCode'))"/>
	</xsl:template>
</xsl:stylesheet>