<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
	<!ENTITY nbsp "&#x00A0;">
]>
<xsl:stylesheet
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:msxml="urn:schemas-microsoft-com:xslt"
	xmlns:umbraco.library="urn:umbraco.library"
	xmlns:CommerceLibrary="urn:CommerceLibrary"
	exclude-result-prefixes="msxml umbraco.library CommerceLibrary">

	<xsl:output method="xml" omit-xml-declaration="yes"/>

	<xsl:param name="currentPage"/>
	<xsl:variable name="catalogName" select="umbraco.library:RequestQueryString('catalog')"/>
	<xsl:variable name="categoryName" select="umbraco.library:RequestQueryString('category')"/>
	<xsl:variable name="campaignItems" select="CommerceLibrary:GetTargetedCampaignItems()"/>

	<xsl:template match="/">
		<xsl:if test="$campaignItems/campaignItems/campaignItem/applyTargets/product[count(../product) > 1]">
			Buy the following product bundle and get a discount of <xsl:value-of select="$campaignItems/campaignItems/campaignItem/awards[count(../applyTargets/product) > 1]/amountOffOrderTotal/@amountOff"/> on your order:
			<xsl:for-each select="$campaignItems/campaignItems/campaignItem/applyTargets/product[count(../product) > 1]">
				<xsl:value-of select="@displayName"/>,&nbsp;
			</xsl:for-each>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="string-length($categoryName) = 0">
				<xsl:variable name="catalog" select="CommerceLibrary:GetCatalog($catalogName)"></xsl:variable>
				<h1>
					<xsl:value-of select="$catalog/productCatalog/@displayName"/>
				</h1>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="category" select="CommerceLibrary:GetCategory($catalogName, $categoryName)"></xsl:variable>
				<h1>
					<xsl:value-of select="$category/category/@displayName"></xsl:value-of>
				</h1>
				<p>
					<xsl:value-of select="$category/category/@description" disable-output-escaping="yes" ></xsl:value-of>
				</p>

				<xsl:apply-templates select="$category/category"></xsl:apply-templates>

			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Display category properties -->
	<xsl:template match="properties"/>

	<!-- Display child categories -->
	<xsl:template match="childCategories">
		<ul id="navlist" style="float:left;">
			<xsl:for-each select="category[@displayOnSite='True']">
				<li>
					<a>
						<xsl:attribute name="href">
							<xsl:value-of select="CommerceLibrary:GetNiceUrlForCategory($catalogName, @id)"/>
						</xsl:attribute>
						<xsl:value-of select="@displayName"/>
					</a>
				</li>
			</xsl:for-each>
		</ul>
	</xsl:template>

	<!-- Display child products -->
	<xsl:template match="childProducts">
		<xsl:for-each select="product">
			<div style="clear: both;">
				<h4>
					<a>
						<xsl:attribute name="href">
							<xsl:value-of select="CommerceLibrary:GetNiceUrlForProduct($catalogName, $categoryName, @id)"/>
						</xsl:attribute>
						<xsl:value-of select="@displayName"/>
					</a>
				</h4>
				<div style="float: left; width: 100px;">
					<img alt="Image">
						<xsl:attribute name="src">
							<xsl:value-of select="umbraco.library:GetMedia(@thumbnailImage, true())/umbracoFile"/>
						</xsl:attribute>
					</img>
				</div>
				<div style="margin-left: 150px">
					<xsl:value-of select="@shortDescription" disable-output-escaping="yes" />
					<xsl:choose>
						<xsl:when test="@allowOrdering">
							Order now!
						</xsl:when>
						<xsl:otherwise>
							Not available right now.
						</xsl:otherwise>
					</xsl:choose>
				</div>
				<div style="margin-left:150px;">
					<xsl:variable name="currentSku" select="@sku"/>
					<xsl:choose>
						<xsl:when test="$campaignItems/campaignItems/campaignItem/product[@sku = $currentSku and @variantSku = '']">
							<span style="text-decoration:line-through">
								<xsl:value-of select="@currency"/>&nbsp;<xsl:value-of select="CommerceLibrary:FormatCurrency(@price)"/>
							</span>
							<br />
							<b>
								<xsl:variable name="amountOff" select="$campaignItems/campaignItems/campaignItem/product[@sku = $currentSku and @variantSku = '']/@amountOff"/>
								<xsl:value-of select="@currency"/>&nbsp;<xsl:value-of select="CommerceLibrary:FormatCurrency(@price - $amountOff)"/>
							</b>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="@currency"/>&nbsp;<xsl:value-of select="CommerceLibrary:FormatCurrency(@price)"/>
						</xsl:otherwise>
					</xsl:choose>
				</div>
			</div>
		</xsl:for-each>
		<div style="clear: both"></div>
	</xsl:template>

	<!-- Display category properties -->
	<xsl:template match="properties"/>

	<!-- Display child categories -->
	<xsl:template match="childCategories">
		<ul id="navlist">
			<xsl:for-each select="category[@displayOnSite='True']">
				<li>
					<a>
						<xsl:attribute name="href">
							<xsl:value-of select="CommerceLibrary:GetNiceUrlForCategory($catalogName, @id)"/>
						</xsl:attribute>
						<xsl:value-of select="@displayName"/>
					</a>
				</li>
			</xsl:for-each>
		</ul>
	</xsl:template>

</xsl:stylesheet>