<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
	<!ENTITY nbsp "&#x00A0;">
]>

<xsl:stylesheet
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:msxml="urn:schemas-microsoft-com:xslt"
	xmlns:umbraco.library="urn:umbraco.library"
	xmlns:CommerceLibrary="urn:CommerceLibrary"
	exclude-result-prefixes="msxml umbraco.library CommerceLibrary">

	<xsl:output method="html" omit-xml-declaration="yes"/>

	<xsl:include href="ProductReview[XSLT].xslt"/>
	<xsl:include href="ReportAbuse[XSLT].xslt"/>

	<xsl:param name="currentPage"/>
	<xsl:variable name="catalogName" select="umbraco.library:RequestQueryString('catalog')"/>
	<xsl:variable name="categoryName" select="umbraco.library:RequestQueryString('category')"/>
	<xsl:variable name="productSku" select="umbraco.library:RequestQueryString('product')"/>

	<xsl:template match="/">

		<script type="text/javascript">
			<![CDATA[
      $(document).ready(function() {
        $('#addNewReviewBtn').click(function() {
          // The callback function settings padding-left to 1px is only a hack to force Chrome to redraw the css
          // If this is not applied the stars won't be visible
          $('#addNewReviewDiv').slideToggle('normal', function(){ $('.star-rating').css('padding-left', '1px'); });       
        });
      });
			]]>
		</script>

		<xsl:variable name="campaignItems" select="CommerceLibrary:GetTargetedCampaignItems()"/>
		<xsl:variable name="product" select="CommerceLibrary:GetProduct($catalogName, $productSku)"></xsl:variable>
		<xsl:variable name="relatedProducts" select="CommerceLibrary:GetRelatedProducts($catalogName, $productSku)"></xsl:variable>
		<xsl:variable name="reviews" select="CommerceLibrary:GetProductReviews($productSku)"></xsl:variable>

		<!-- See AddToBasket.xslt for add to basket method call. -->
		<!-- See AddProductReview.xslt for add product review method call. -->
		<!-- See AddProductReviewComment.xslt for add product review comment method call. -->

		<!-- Google product review, read more here http://www.google.com/support/webmasters/bin/answer.py?answer=146645 -->
		<div itemscope="" itemtype="http://data-vocabulary.org/Review-aggregate">
			<h1>
				<span itemprop="itemreviewed">
					<xsl:value-of select="$product/product/@displayName"/>
				</span>
			</h1>

			<span itemprop="rating" itemscope="" itemtype="http://data-vocabulary.org/Rating" style="display:none;">
				<span itemprop="average">
					<xsl:value-of select="$product/product/@rating" />
				</span>
				<span itemprop="best">100</span>
				<span itemprop="votes">
					<xsl:value-of select="count($reviews/productReviews/productReview[(@status='Approved' or @status='ReportedAsAbuse')])"/>
				</span>
			</span>

			<div style="float: left; width: 150px;">
				<img alt="Image">
					<xsl:attribute name="src">
						<xsl:value-of select="umbraco.library:GetMedia($product/product/@thumbnailImage, true())/umbracoFile"/>
					</xsl:attribute>
				</img>
			</div>
			<div>
				<h4>Short Description</h4>
				<xsl:value-of select="$product/product/@shortDescription" disable-output-escaping="yes" />
				<h4>Long Description</h4>
				<xsl:value-of select="$product/product/@longDescription" disable-output-escaping="yes" />
			</div>
			<div>
				<h4>
					Your Price:<br />
					<xsl:variable name="currentSku" select="$product/product/@sku"/>
					<xsl:choose>
						<xsl:when test="$campaignItems/campaignItems/campaignItem/product[@sku = $currentSku and @variantSku = '']">
							<span style="text-decoration:line-through">
								<xsl:value-of select="$product/product/@currency"/>&nbsp;<xsl:value-of select="CommerceLibrary:FormatCurrency($product/product/@price)"/>
							</span>
							<br />
							<xsl:variable name="amountOff" select="$campaignItems/campaignItems/campaignItem/product[@sku = $currentSku and @variantSku = '']/@amountOff"/>
							<b>
								<xsl:value-of select="$product/product/@currency"/>&nbsp;<xsl:value-of select="CommerceLibrary:FormatCurrency($product/product/@price - $amountOff)"/>
							</b>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$product/product/@currency"/>&nbsp;<xsl:value-of select="CommerceLibrary:FormatCurrency($product/product/@price)"/>
						</xsl:otherwise>
					</xsl:choose>
				</h4>
				<span>
					<xsl:choose>
						<xsl:when test="$product/product/@allowOrdering">
							<form method="post">
								<input type="hidden" name="sku">
									<xsl:attribute name="value">
										<xsl:value-of select="$product/product/@sku"/>
									</xsl:attribute>
								</input>
								Quantity: <input type="text" name="quantityInput" value="1"></input>&nbsp;
								<xsl:if test="$product/product/@hasVariants = 'True'">
									<select name="variantSku">
										<option>Please select</option>
										<xsl:for-each select="$product/product/variants/product">
											<option>
												<xsl:attribute name="value">
													<xsl:value-of select="@variantSku"/>
												</xsl:attribute>
												<xsl:value-of select="@displayName"/>
											</option>
										</xsl:for-each>
									</select>&nbsp;
								</xsl:if>
								<input type="submit" value="Add To Basket"></input>
							</form>
						</xsl:when>
						<xsl:otherwise>
							<p style="color: red;">
								<xsl:value-of select="$product/product/@sku"/> is temporarily unavailable.
							</p>
						</xsl:otherwise>
					</xsl:choose>
				</span>
			<meta property="v:pricerange">
				<xsl:attribute name="content">
					<xsl:value-of select="$product/product/@currency"/>&nbsp;<xsl:value-of select="CommerceLibrary:FormatCurrency($product/product/@price)"/>
				</xsl:attribute>
			</meta>
			</div>
			<div>
				<h4>Related Products</h4>
				<ul>
					<xsl:apply-templates select="$relatedProducts/relatedProducts/productRelationType/product" />
				</ul>
			</div>
			<div>
				<h4>Reviews</h4>
				<span id="addNewReviewBtn" class="spanLink">Add new review</span>
				<div id="addNewReviewDiv" style="display:none; margin-top:10px;">
					<form method="post">
						<input type="hidden" name="skuInput">
							<xsl:attribute name="value">
								<xsl:value-of select="$product/product/@sku"/>
							</xsl:attribute>
						</input>
						Firstname<br />
						<input type="text" name="firstNameInput" style="width:300px;" />
						<br />
						Lastname<br />
						<input type="text" name="lastNameInput" style="width:300px;" />
						<br />
						E-mail<br />
						<input type="text" name="emailInput" style="width:300px;" />
						<br />
						Rating<br />
						<input type="radio" name="ratingInput" value="20" class="star" />
						<input type="radio" name="ratingInput" value="40" class="star" />
						<input type="radio" name="ratingInput" value="60" class="star" />
						<input type="radio" name="ratingInput" value="80" class="star" />
						<input type="radio" name="ratingInput" value="100" class="star" />
						<br />
						Headline<br />
						<input type="text" name="reviewHeadlineInput" style="width:600px;" />
						<br />
						Review
						<br />
						<!-- xsl:text and break is there to avoid HTML being wrapped in the textarea -->
						<textarea name="reviewTextInput" style="height:100px; width:600px;">
							<xsl:text>
</xsl:text>
						</textarea>
						<br />
						<input type="submit" value="Add review" />
					</form>
				</div>
				<br />
				<br />
				<xsl:apply-templates select="$reviews/productReviews" />
			</div>
		</div>
		<div style="clear: both"></div>

	</xsl:template>

	<xsl:template match="product">
		<li>
			<a>
				<xsl:attribute name="href">
					<xsl:value-of select="CommerceLibrary:GetNiceUrlForProduct($catalogName, $categoryName, @id)"/>
				</xsl:attribute>
				<xsl:value-of select="@displayName"/>
			</a>&nbsp;
			<span class="pricerange">
				<xsl:value-of select="@currency"/>&nbsp;
				<xsl:value-of select="CommerceLibrary:FormatCurrency(@price)"/>
			</span>
		</li>
	</xsl:template>

	<xsl:template match="productReviews">
		<xsl:for-each select="productReview[(@status='Approved' or @status='ReportedAsAbuse') and string-length(@reviewHeadline) > 0 and string-length(@reviewText) > 0]">
			<xsl:sort select="@helpful" data-type="number" order="descending"/>
			<xsl:call-template name="productReview">
				<xsl:with-param name="review" select="self::node()"/>
			</xsl:call-template>
			<a>
				<xsl:attribute name="href">
					/productReviewWithComments.aspx?catalog=<xsl:value-of select="$catalogName"/>&amp;productReviewId=<xsl:value-of select="@id"/>
				</xsl:attribute>
				Comments:&nbsp;(<xsl:value-of select="count(comments/comment[(@status='Approved' or @status='ReportedAsAbuse') and @commentText != ''])"/>)
			</a>&nbsp;<br />
			Was this review helpful to you?
			<a onclick="return confirm('Give vote on this review?')">
				<xsl:attribute name="href">
					?productReviewId=<xsl:value-of select="@id"/>&amp;helpful=1
				</xsl:attribute>Yes
			</a>&nbsp;
			<a onclick="return confirm('Give vote on this review?')">
				<xsl:attribute name="href">
					?&amp;productReviewId=<xsl:value-of select="@id"/>&amp;helpful=0
				</xsl:attribute>
				No
			</a>&nbsp;
			<a onclick="return confirm('Report this review as abuse?')">
				<xsl:attribute name="href">
					?reportReviewAsAbuse=<xsl:value-of select="@id"/>
				</xsl:attribute>
				Report abuse
			</a>
			<br />
			<br />
			<br />
		</xsl:for-each>
	</xsl:template>


</xsl:stylesheet>